aboutsummaryrefslogtreecommitdiff
path: root/library/src/main/java/com/bumptech/glide/Glide.java
diff options
context:
space:
mode:
Diffstat (limited to 'library/src/main/java/com/bumptech/glide/Glide.java')
-rw-r--r--library/src/main/java/com/bumptech/glide/Glide.java16
1 files changed, 8 insertions, 8 deletions
diff --git a/library/src/main/java/com/bumptech/glide/Glide.java b/library/src/main/java/com/bumptech/glide/Glide.java
index 5439a42a..b082740e 100644
--- a/library/src/main/java/com/bumptech/glide/Glide.java
+++ b/library/src/main/java/com/bumptech/glide/Glide.java
@@ -10,8 +10,8 @@ import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.os.ParcelFileDescriptor;
-import android.support.v4.app.Fragment;
-import android.support.v4.app.FragmentActivity;
+import androidx.fragment.app.Fragment;
+import androidx.fragment.app.FragmentActivity;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
@@ -576,8 +576,8 @@ public class Glide {
*
* @see #with(android.app.Activity)
* @see #with(android.app.Fragment)
- * @see #with(android.support.v4.app.Fragment)
- * @see #with(android.support.v4.app.FragmentActivity)
+ * @see #with(androidx.fragment.app.Fragment)
+ * @see #with(androidx.fragment.app.FragmentActivity)
*
* @param context Any context, will not be retained.
* @return A RequestManager for the top level application that can be used to start a load.
@@ -600,8 +600,8 @@ public class Glide {
}
/**
* Begin a load with Glide that will tied to the give {@link android.support.v4.app.FragmentActivity}'s lifecycle
* and that uses the given {@link android.support.v4.app.FragmentActivity}'s default options.
*
* @param activity The activity to use.
* @return A RequestManager for the given FragmentActivity that can be used to start a load.
@@ -625,8 +625,8 @@ public class Glide {
}
/**
* Begin a load with Glide that will be tied to the given {@link android.support.v4.app.Fragment}'s lifecycle and
* that uses the given {@link android.support.v4.app.Fragment}'s default options.
*
* @param fragment The fragment to use.
* @return A RequestManager for the given Fragment that can be used to start a load.
@@ -600,8 +600,8 @@ public class Glide {
}
/**
- * Begin a load with Glide that will tied to the give {@link android.support.v4.app.FragmentActivity}'s lifecycle
- * and that uses the given {@link android.support.v4.app.FragmentActivity}'s default options.
+ * Begin a load with Glide that will tied to the give {@link androidx.fragment.app.FragmentActivity}'s lifecycle
+ * and that uses the given {@link androidx.fragment.app.FragmentActivity}'s default options.
*
* @param activity The activity to use.
@@ -625,8 +625,8 @@ public class Glide {
}
/**
- * Begin a load with Glide that will be tied to the given {@link android.support.v4.app.Fragment}'s lifecycle and
- * that uses the given {@link android.support.v4.app.Fragment}'s default options.
+ * Begin a load with Glide that will be tied to the given {@link androidx.fragment.app.Fragment}'s lifecycle and
+ * that uses the given {@link androidx.fragment.app.Fragment}'s default options.
*
* @param fragment The fragment to use.